==> x-ui-vue3-0.2.1.tgz: package/esm/table/index.js <==
import { defineComponent, ref, computed, provide, createVNode } from 'vue';
import { dataTableContextKey } from './interface.js';
import TableHeader from './TableHeader.js';
import TableBody from './TableBody.js';

const tableProps = {
  prefixCls: {
    default: "x-table"
  },
  columns: Array,
  data: Array,
  rowProps: Function,
  maxHeight: Number,
  rowClass: [String, Function],
  bordered: Boolean,
  bottomBordered: {
    default: true
  },
  scrollX: Number,
  virtualScroll: Boolean,
  size: {
    type: String,
    default: "medium"
  }
};
const Table = defineComponent({
  name: "x-table",
  props: tableProps,
  setup(props, {
    slots
  }) {
    const headerRef = ref();
    const bodyRef = ref();
    const leftFixedColumsRef = computed(() => {
      var _a;
      return (_a = props.columns) == null ? void 0 : _a.filter((col) => col.fixed === "left");
    });
    const rightFixedColumsRef = computed(() => {
      var _a;
      return (_a = props.columns) == null ? void 0 : _a.filter((col) => col.fixed === "right");
    });
    const fixedColumnLeftMapRef = computed(() => {
      let left = 0;
      return leftFixedColumsRef.value.reduce((map, col) => (map[col.key] = left, left += col.width || 0, map), {});
    });
    const fixedColumnRightMapRef = computed(() => {
      let right = 0;
      return rightFixedColumsRef.value.reverse().reduce((map, col) => (map[col.key] = right, right += col.width || 0, map), {});
    });
    let scrollType = "";
    let lastLeft = 0;
    function onHeaderScroll(el) {
      scrollType = "header";
      syncScroll(el);
    }
    function onBodyScroll(el) {
      scrollType = "body";
      syncScroll(el);
    }
    function syncScroll(el) {
      if (el.target.scrollLeft == lastLeft)
        return;
      lastLeft = el.target.scrollLeft;
      if (scrollType === "header") {
        ;
        bodyRef.value.$el.scrollLeft = lastLeft;
      } else {
        if (!headerRef.value)
          return;
        headerRef.value.$el.scrollLeft = lastLeft;
      }
    }
    provide(dataTableContextKey, {
      props,
      leftFixedColumsRef,
      rightFixedColumsRef,
      fixedColumnLeftMapRef,
      fixedColumnRightMapRef
    });
    return () => {
      const {
        prefixCls,
        maxHeight,
        bordered,
        bottomBordered
      } = props;
      const scrollable = !!maxHeight;
      const cls = [prefixCls, bordered && `${prefixCls}-bordered`, bottomBordered && `${prefixCls}-bottom-bordered`];
      return createVNode("div", {
        "class": cls
      }, [scrollable && createVNode(TableHeader, {
        "discrete": true,
        "ref": headerRef,
        "onScroll": onHeaderScroll
      }, null), createVNode(TableBody, {
        "showHeader": !scrollable,
        "ref": bodyRef,
        "onScroll": onBodyScroll
      }, slots)]);
    };
  }
});
Table.install = (app) => {
  app.component(Table.name, Table);
};

export { Table as default };

==> x-ui-vue3-0.2.3.tgz: package/esm/table/index.js <==
import { defineComponent, ref, computed, provide, createVNode } from 'vue';
import { dataTableContextKey } from './interface.js';
import TableHeader from './TableHeader.vue.js';
import TableBody from './TableBody.js';

const tableProps = {
  prefixCls: {
    default: "x-table"
  },
  columns: Array,
  data: Array,
  rowProps: Function,
  maxHeight: Number,
  rowClass: [String, Function],
  bordered: Boolean,
  bottomBordered: {
    default: true
  },
  scrollX: Number,
  virtualScroll: Boolean,
  size: {
    type: String,
    default: "medium"
  }
};
const Table = defineComponent({
  name: "x-table",
  props: tableProps,
  setup(props, {
    slots
  }) {
    const headerRef = ref();
    const bodyRef = ref();
    const leftFixedColumsRef = computed(() => {
      var _a;
      return (_a = props.columns) == null ? void 0 : _a.filter((col) => col.fixed === "left");
    });
    const rightFixedColumsRef = computed(() => {
      var _a;
      return (_a = props.columns) == null ? void 0 : _a.filter((col) => col.fixed === "right");
    });
    const fixedColumnLeftMapRef = computed(() => {
      let left = 0;
      return leftFixedColumsRef.value.reduce((map, col) => (map[col.key] = left, left += col.width || 0, map), {});
    });
    const fixedColumnRightMapRef = computed(() => {
      let right = 0;
      return rightFixedColumsRef.value.reverse().reduce((map, col) => (map[col.key] = right, right += col.width || 0, map), {});
    });
    let lastLeft = 0;
    function onHeaderScroll(e) {
      syncScroll(e, true);
    }
    function onBodyScroll(e) {
      syncScroll(e, false);
    }
    function syncScroll(e, header) {
      if (e.target.scrollLeft == lastLeft)
        return;
      lastLeft = e.target.scrollLeft;
      if (header) {
        ;
        bodyRef.value.$el.scrollLeft = lastLeft;
      } else {
        if (!headerRef.value)
          return;
        headerRef.value.$el.scrollLeft = lastLeft;
      }
    }
    provide(dataTableContextKey, {
      props,
      leftFixedColumsRef,
      rightFixedColumsRef,
      fixedColumnLeftMapRef,
      fixedColumnRightMapRef
    });
    return () => {
      const {
        prefixCls,
        bordered,
        bottomBordered
      } = props;
      const cls = [prefixCls, bordered && `${prefixCls}-bordered`, bottomBordered && `${prefixCls}-bottom-bordered`];
      return createVNode("div", {
        "class": cls
      }, [createVNode(TableHeader, {
        "ref": headerRef,
        "onScroll": onHeaderScroll
      }, null), createVNode(TableBody, {
        "ref": bodyRef,
        "onScroll": onBodyScroll
      }, slots)]);
    };
  }
});
Table.install = (app) => {
  app.component(Table.name, Table);
};

export { Table as default };
